<?php
/*
 * $Id: Session.class.php 5251 2010-09-12 13:58:48Z jjocal $
 *
 * Copyright 2001, 2008 Thomas Belliard
 *
 * This file is part of GEPI.
 *
 * GEPI is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GEPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GEPI; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


# Cette classe sert  manipuler la session en cours.
# Elle gre notamment l'authentification des utilisateurs
#  partir de diffrentes sources.

function my_warning_handler($errno, $errstr) {
    if ($errno == E_WARNING && strpos($errstr, 'PHP_Incomplete_Class') !== false)  {
	//ignore warning, this one is probably due to propel unserialization wuthout correct class declaration
    	return true;
    } else {
	return false;
    }
}

class Session {
	public $login = false;
	public $nom = false;
	public $prenom = false;
	public $statut = false;
	public $statut_special = false;
	public $statut_special_id = false;
	public $start = false;
	public $matiere = false;
	public $maxLength = "30"; # Dure par dfaut d'une session utilisateur : 30 minutes.
	public $rne = false; # false, n RNE valide. Utilis par le multisite.
	public $auth_locale = true; # true, false. Par dfaut, on utilise l'authentification locale
	public $auth_ldap = false; # false, true
	public $auth_sso = false; # false, cas, lemon, lcs
	public $current_auth_mode = false;  # gepi, ldap, sso, ou false : le mode d'authentification
										# utilis par l'utilisateur actuellement connect

	private $etat = false; 	# actif/inactif. Utilis simplement en interne pour vrifier que
							# l'utilisateur authentifi de source externe est bien actif dans Gepi.

	public function __construct() {

		# On initialise la session
		session_name("GEPI");

		set_error_handler("my_warning_handler", E_WARNING);
		session_start();
		restore_error_handler();

		# Avant de faire quoi que ce soit, on initialise le fuseau horaire
		if (isset($GLOBALS['timezone']) && $GLOBALS['timezone'] != '') {
		    $this->update_timezone($GLOBALS['timezone']);
                }

		$this->maxLength = getSettingValue("sessionMaxLength");
		$this->verif_CAS_multisite();

		# On charge les valeurs dj prsentes en session
		$this->load_session_data();
		# On charge des lments de configuration lis  l'authentification
		$this->auth_locale = getSettingValue("auth_locale") == 'yes' ? true : false;
		$this->auth_ldap = getSettingValue("auth_ldap") == 'yes' ? true : false;
		$this->auth_sso = in_array(getSettingValue("auth_sso"), array("lemon", "cas", "lcs")) ? getSettingValue("auth_sso") : false;
		if (!$this->is_anonymous()) {
		  # Il s'agit d'une session non anonyme qui existait dj.
		  # On regarde s'il n'y a pas de timeout
		  if ($this->timeout()) {
		  	# timeout : on remet  zro.
		  	$debut_session = $_SESSION['start'];
		  	$this->reset(3);
		  	if (isset($GLOBALS['niveau_arbo'])) {
		  		if ($GLOBALS['niveau_arbo'] == "0") {
		  			$logout_path = "./logout.php";
		  		} elseif ($GLOBALS['niveau_arbo'] == "2") {
		  			$logout_path = "../../logout.php";
		  		} elseif ($GLOBALS['niveau_arbo'] == "3") {
		  			$logout_path = "../../../logout.php";
		  		} else {
		  			$logout_path = "../logout.php";
		  		}
		  	} else {
		  		$logout_path = "../logout.php";
		  	}
		  	header("Location:".$logout_path."?auto=3&debut_session=".$debut_session."&session_id=".session_id());
		  	exit();
		  } else {
		  	# Pas de timeout : on met  jour le log
		  	$this->update_log();
		  }
		}

	}

	# S'agit-il d'une session anonyme ?
	public function is_anonymous() {
		# Retourne 'true' si login == false
		return !$this->login;
	}

	# Authentification d'un utilisateur pour la session
	# Cette mthode remplace l'ancienne fonction openSession(...)
	# Valeurs retournes :
	# 1 : authentification valide
	# 2 : compte bloqu : trop de tentatives errones
	# 3 : l'IP utilise pour se connecter est bloque
	# 4	: authentification externe russie, mais utilisateurs dfini comme 'inactif'
	# 5 : authentification externe russie, mais utilisateur dfini pour une authentification autre
	# 6 : authentification externe russie, mais compte inexistant en local et impossible d'importer depuis une source externe
	# 7 : l'administrateur a dsactiv les connexions  Gepi.
	# 8 : multisite ; impossibilit d'obtenir le RNE de l'utilisateur qui s'est authentifi correctement.
	# 9 : chec de l'authentification (mauvais couple login/mot de passe, sans doute).
	public function authenticate($_login = null, $_password = null) {

		// Quelques petits tests de scurit

	    // Vrification de la liste noire des adresses IP
	    if (isset($GLOBALS['liste_noire_ip']) && in_array($_SERVER['REMOTE_ADDR'], $GLOBALS['liste_noire_ip'])) {
		  tentative_intrusion(1, "Tentative de connexion depuis une IP sur liste noire (login utilis : ".$_login.")");
	      return "3";
		  die();
	    }

	    // On initialise la session de l'utilisateur.
	    // On commence par extraire le mode d'authentification dfini
	    // pour l'utilisateur. Si l'utilisateur n'existe pas, on essaiera
	    // l'authentification LDAP et le SSO quand mme.
		$auth_mode = self::user_auth_mode($_login);
    
		switch ($auth_mode) {
			case "gepi":
			  # Authentification locale sur la base de donnes Gepi
			  $auth = $this->authenticate_gepi($_login,$_password);
			break;
			case "ldap":
			  # Authentification sur un serveur LDAP
			  $auth = $this->authenticate_ldap($_login,$_password);
			break;
			case "sso":
			  # Authentification gre par un service de SSO
			  # On n'a pas besoin du login ni du mot de passe
			  switch ($this->auth_sso) {
			  	case "cas":
			  		$auth = $this->authenticate_cas();
			  	break;
			  	case "lemon":
			  		$auth = $this->authenticate_lemon();
			  	break;
			  	case "lcs":
			  		$auth = $this->authenticate_lcs();
			  	break;
			  }
			break;
			case false:
			  # L'utilisateur n'existe pas dans la base de donnes ou bien
			  # n'a pas t pass en paramtre.
			  # On va donc tenter d'abord une authentification LDAP,
			  # puis une authentification SSO,  condition que celles-ci
			  # soient bien sr configures.
			  if ($this->auth_ldap && $_login != null && $_password != null) {
			  	$auth = $this->authenticate_ldap($_login,$_password);
			  } else if ($this->auth_sso && $_login == null) {
			  	// L'auth LDAP n'a pas march, on essaie le SSO
				 switch ($this->auth_sso) {
				  	case "cas":
				  		$auth = $this->authenticate_cas();
				  	break;
				  	case "lemon":
				  		$auth = $this->authenticate_lemon();
				  	break;
				  	case "lcs":
				  		$auth = $this->authenticate_lcs();
				  	break;
				 }
			  } else {
			  	$auth = false;
			  }
			break;
			default:
			  # Si on arrive l, c'est qu'il y a un problme avec la dfinition
			  # du mode d'authentification pour l'utilisateur en question.
			  $auth = false;
			break;
		}

		// A partir d'ici soit on a un avis d'chec de l'authentification, soit
		// une session valide.
		if ($auth) {
			// L'authentification en elle-mme est valide.

			// Dans le cas du multisite, il faut maintenant dterminer le RNE
			// de l'utilisateur avant d'aller plus loin, sauf s'il a dj t pass
			// en paramtre.
			if (isset($GLOBALS['multisite']) && $GLOBALS['multisite'] == "y") {

				if (!isset($_GET['rne']) AND (!isset($_COOKIE["RNE"]) OR $_COOKIE["RNE"] == 'RNE')) {
          if (isset($GLOBALS['mode_choix_base']) && $GLOBALS['mode_choix_base'] == "url"){
            // dans ce cas, on se connecte  l'url $url_cas_sso donne par le secure/connect.inc.php
            $t_rne = file_get_contents($GLOBALS[url_cas_sso] . '?login=' . $this->login . '&cle=' . $GLOBALS['cle_url_cas']);
            if ($t_rne != 'erreur'){
              $rep_rne = explode("|", $t_rne);
              $nbre_rne = count($rep_rne);
              if ($nbre_rne > 1){
                header("Location: choix_rne.php?nbre=".$nbre_rne."&lesrne=".$t_rne);
								exit();
              }else{
                if ($this->current_auth_mode == "sso") {
									setcookie('RNE', $t_rne);
									header("Location: login_sso.php?rne=".$t_rne);
									exit();
								} else {
									header("Location: login.php?rne=".$t_rne);
									exit();
								}
              }
            }
          }elseif (LDAPServer::is_setup()) {
						// Le RNE n'a pas t transmis. Il faut le rcuprer et recharger la page
						// pour obtenir la bonne base de donnes
						$ldap = new LDAPServer;
						$user = $ldap->get_user_profile($this->login);
						// On teste pour savoir si on a plusieurs RNE
						$test = count($user["rne"]);

						if ($test >= 1) {
							# On a au moins un RNE, on peut continuer
							if ($test > 1) {
								// On envoie l'utilisateur choisir lui mme son RNE
								$rnes = NULL;
								for($a = 0 ; $a < $test ; $a++){
									$rnes .= $user["rne"][$a].'|';
								}

								header("Location: choix_rne.php?nbre=".$test."&lesrne=".$rnes);
								exit();

							}else{
								// Il n'y en a qu'un, on recharge !
								if ($this->current_auth_mode == "sso") {
									setcookie('RNE', $user["rne"][0]);
									header("Location: login_sso.php?rne=".$user["rne"][0]);
									exit();
								} else {
									header("Location: login.php?rne=".$user["rne"][0]);
									exit();
								}
							}

						} else {
							return "8";
							exit();
						}
					} else {
						return "8";
						exit();
					}
				}
			}


			// On va maintenant effectuer quelques tests pour vrifier
			// que le compte n'est pas bloqu.
			if ($this->account_is_locked()) {
				$this->reset(2);
				return "2";
				exit();
			}

			# On charge les donnes de l'utilisateur
			if (!$this->load_user_data()) {
				# Si on ne parvient pas  charger les donnes, c'est que
				# l'utilisateur n'est pas prsent en base de donnes.
				# On essaie d'importer son profil depuis le LDAP.
        
        # Si on a activ la synchro Scribe, on utilise alors l'import spcifique
				if (getSettingValue("may_import_user_profile") == "yes" && getSettingValue("sso_scribe") == "yes") {
          $load = $this->import_user_profile_from_scribe();
        
        # Sinon, on utilise l'import classique, trs basique.
        } elseif (getSettingValue("may_import_user_profile")) {
          $load = $this->import_user_profile();
        }
        if (!$load) {
          return "6";
          exit();
        } else {
          # Si l'import a russi, on tente  nouveau de charger
          # les donnes de l'utilisateur.
          $this->load_user_data();
        }
			}

			# On vrifie que l'utilisateur est bien actif
			if ($this->etat != "actif") {
				$this->reset(2);
				return "4";
				exit();
			}

			# On vrifie que les connexions sont bien actives.
		    $disable_login = getSettingValue("disable_login");
		    if ($this->statut != "administrateur" && ($disable_login == "yes" || $disable_login == "soft")) {
		    	$this->reset(2);
		    	return "7";
		    	exit();
		    }

			# On teste la cohrence de mode de connexion
		    $auth_mode = self::user_auth_mode($this->login);
		    if ($auth_mode != $this->current_auth_mode) {
		    	$this->reset(2);
		    	return "5";
		    	exit;
		    }

			# Tout est bon. On valide dfinitivement la session.
			$this->start = mysql_result(mysql_query("SELECT now();"),0);
			$_SESSION['start'] = $this->start;
			$this->insert_log();
			# On supprime l'historique des logs conformment  la dure dfinie.
			sql_query("delete from log where START < now() - interval " . getSettingValue("duree_conservation_logs") . " day and END < now()");

			# On envoie un mail, si l'option a t active
			mail_connexion();
			return "1";
			exit();
		} else {
			// L'authentification a chou.
			// On nettoie la session.
			$this->reset(2);

			// On enregistre l'chec.
			// En cas d'chec rpt, on renvoie un code d'erreur de
			// verrouillage de compte, pour brouiller les pistes en cas
			// d'attaque brute-force sur les logins.
			if ($this->record_failed_login($_login)) {
				return "2";
				exit();
			}

			// On retourne le code d'erreur gnrique
			return "9";
		}

	}

	# La mthode ci-dessous est appele lorsque l'on veut s'assurer que l'on a
	# un utilisateur correctement authentifi, et qu'il est bien autoris 
	# l'tre. Elle remplace la fonction resumeSession qui tait pralablement utilise.
	public function security_check() {
		# Codes renvoys :
		# 0 = logout automatique
		# 1 = session valide
		# c = changement forc de mot de passe

		# D'abord on regarde si on a une tentative d'accs anonyme  une page protge :
		if ($this->is_anonymous()) {
			tentative_intrusion(1, "Accs  une page sans tre logu (peut provenir d'un timeout de session).");
			return "0";
			exit;
		}

		$sql = "SELECT statut, change_mdp, etat FROM utilisateurs where login = '" . $this->login . "'";
		$res = sql_query($sql);
		$row = mysql_fetch_object($res);

		$change_password = $row->change_mdp != "n" ? true : false;
		$statut_ok = $this->statut == $row->statut ? true : false;
		$etat_ok = $row->etat == "actif" ? true : false;
		$login_allowed = getSettingValue("disable_login") == "yes" ? false : true;

		if (!$login_allowed && $this->statut != "administrateur") {
			return "0";
			exit;
		}

		if (!$statut_ok) {
			return "0";
			exit;
		}

		if (!$etat_ok) {
			return "0";
			exit;
		}

		// Si on est l, ce que l'utilisateur a le droit de rester.

		if ($change_password &&
				($this->current_auth_mode == "gepi" || getSettingValue("ldap_write_access") == "yes"))
			{
				return "c";
			}

		# Mieux vaut deux fois qu'une...
		if ($statut_ok && $etat_ok && ($login_allowed || $this->statut == "administrateur")) {
			return "1";
			exit;
		}
	}

	# On regarde si l'utilisateur existe dans la base de donnes,
	# et on vrifie quel est le mode d'authentification dfini.
	public static function user_auth_mode($_login) {
		if ($_login == null) {
			return false;
			die();
		}

		$req = mysql_query("SELECT auth_mode FROM utilisateurs WHERE UPPER(login) = '".strtoupper($_login)."'");
		if (mysql_num_rows($req) == 0) {
			return false;
		} else {
			return mysql_result($req, 0, "auth_mode");
		}
	}

	public function close ($_auto) {
		// $_auto_ reprend les codes de reset()
		$this->reset($_auto);
	}


	// Recrer le log dans la table logs.
	// ATTENTION ! Cette mthode n'est utile que dans un cas trs particulier :
	// la restauration d'une sauvegarde, qui compromet la session en cours de
	// l'administrateur. Elle ne devrait jamais tre utilise dans un autre
	// cas.
	// A noter : la mthode ne rinitialise pas la session. Elle ne fait que
	// renregistrer la session en cours dans la base de donnes.
	public function recreate_log() {
		// On teste que le login enregistr en session existe bien dans la table
		// des utilisateurs. Ceci est pour vrifier que cette opration de
		// rcriture du log est bien ncessaire, et valide !
		if ($this->login == '') {
			return false;
		} else {
			$test = mysql_num_rows(mysql_query("SELECT login FROM utilisateurs WHERE login = '".$this->login."'"));
			if ($test == 0) {
				return false;
			} else {
				return $this->insert_log();
			}
		}
	}

	## METHODE PRIVEES ##

	// Cration d'une entre de log
	private function insert_log() {
		if (!isset($_SERVER['HTTP_REFERRER'])) $_SERVER['HTTP_REFERER'] = '';
	    $sql = "INSERT INTO log (LOGIN, START, SESSION_ID, REMOTE_ADDR, USER_AGENT, REFERER, AUTOCLOSE, END) values (
	                '" . $this->login . "',
	                '" . $this->start . "',
	                '" . session_id() . "',
	                '" . $_SERVER['REMOTE_ADDR'] . "',
	                '" . $_SERVER['HTTP_USER_AGENT'] . "',
	                '" . $_SERVER['HTTP_REFERER'] . "',
	                '1',
	                '" . $this->start . "' + interval " . $this->maxLength . " minute
	            )
	        ;";
	    $res = sql_query($sql);
	}

	// Mise  jour du log de l'utilisateur
	private function update_log() {
		if ($this->is_anonymous()) {
			return false;
		} else {
			$sql = "UPDATE log SET END = now() + interval " . $this->maxLength . " minute where SESSION_ID = '" . session_id() . "' and START = '" . $this->start . "'";
        	$res = sql_query($sql);
		}
	}

	// Dans le cas du multisite on vrifie si la session a t initialise dans la bonne base
	private function verif_CAS_multisite(){

		if (isset($_GET['rne']) AND $GLOBALS['multisite'] == 'y' AND isset($_SESSION["login"])) {
			// Alors, on initialise la session ici

			$this->start = mysql_result(mysql_query("SELECT now();"),0);
			$_SESSION['start'] = $this->start;
			$this->recreate_log();

		}
	}

	// Test pour voir si la session de l'utilisateur est en timeout
	private function timeout() {
    	$sql = "SELECT now() > END TIMEOUT from log where SESSION_ID = '" . session_id() . "' and START = '" . $this->start . "'";
    	return sql_query1($sql);
	}

	// Remise  zro de la session : on supprime toutes les informations prsentes
	private function reset($_auto = "0") {
		# Codes utiliss pour $_auto :
		# 0 : logout normal
		# 2 : logout renvoy par la fonction checkAccess (problme gepiPath ou accs interdit)
		# 3 : logout li  un timeout

	    # On teste 'start' simplement pour simplement vrifier que la session n'a pas encore t ferme.
	    if ($this->start) {
	      $sql = "UPDATE log SET AUTOCLOSE = '" . $_auto . "', END = now() where SESSION_ID = '" . session_id() . "' and START = '" . $this->start . "'";
              $res = sql_query($sql);
	   }

	   // Dtruit toutes les variables de session
	    session_unset();
	    $_SESSION = array();

	    // Dtruit le cookie sur le navigateur
	    $CookieInfo = session_get_cookie_params();
	    @setcookie(session_name(), '', time()-3600, $CookieInfo['path']);

	    // dtruit la session sur le serveur
	    session_destroy();
	}

	private function load_session_data() {
		# On ne met  jour que si la variable de session est assigne.
		# Si elle est assigne et null, on met 'false'.
		if (isset($_SESSION['login'])) {
			$this->login 	= $_SESSION['login'] != null ? $_SESSION["login"] : false;
		}
		if (isset($_SESSION['nom'])) {
			$this->nom 	= $_SESSION['nom'] != null ? $_SESSION["nom"] : false;
		}
		if (isset($_SESSION['prenom'])) {
			$this->prenom 	= $_SESSION['prenom'] != null ? $_SESSION["prenom"] : false;
		}
		if (isset($_SESSION['statut'])) {
			$this->statut 	= $_SESSION['statut'] != null ? $_SESSION["statut"] : false;
		}
		if (isset($_SESSION['start'])) {
			$this->start 	= $_SESSION['start'] != null ? $_SESSION["start"] : false;
		}
		if (isset($_SESSION['matiere'])) {
			$this->matiere 	= $_SESSION['matiere'] != null ? $_SESSION["matiere"] : false;
		}
		if (isset($_SESSION['rne'])) {
			$this->rne 	= $_SESSION['rne'] != null ? $_SESSION["rne"] : false;
		}
		if (isset($_SESSION['statut_special'])) {
			$this->statut_special 	= $_SESSION['statut_special'] != null ? $_SESSION["statut_special"] : false;
		}
		if (isset($_SESSION['statut_special_id'])) {
			$this->statut_special_id 	= $_SESSION['statut_special_id'] != null ? $_SESSION["statut_special_id"] : false;
		}
		if (isset($_SESSION['maxLength'])) {
			$this->maxLength 	= $_SESSION['maxLength'] != null ? $_SESSION["maxLength"] : false;
		}
		if (isset($_SESSION['current_auth_mode'])) {
			$this->current_auth_mode 	= $_SESSION['current_auth_mode'] != null ? $_SESSION["current_auth_mode"] : false;
		}
	}

	# Cette fonction permet de tester sous quelle forme le login est stock dans la base
	# de donnes. Elle renvoie true ou false.
	private function use_uppercase_login($_login) {
		// On dtermine si l'utilisateur a un login en majuscule ou minuscule
		$test_uppercase = "SELECT login FROM utilisateurs WHERE (login = '" . strtoupper($_login) . "')";
		if (sql_count(sql_query($test_uppercase)) == "1") {
			return true;
		} else {
			# On a false soit si l'utilisateur n'est pas prsent dans la base, soit s'il est
			# en minuscule.
			return false;
		}
	}

	private function authenticate_gepi($_login,$_password) {
		if ($this->use_uppercase_login($_login)) {
			# On passe le login en majuscule pour toute la session.
			$_login = strtoupper($_login);
		}
		$sql = "SELECT login, password FROM utilisateurs WHERE (login = '" . $_login . "' and etat != 'inactif')";
		$query = mysql_query($sql);
		if (mysql_num_rows($query) == "1") {
			# Un compte existe avec ce login
			if (mysql_result($query, 0, "password") == md5($_password)) {
				# Le mot de passe correspond. C'est bon !
				$this->login = $_login;
				$this->current_auth_mode = "gepi";
				return true;
			} else {
				return false;
			}
		} else {
			# Le login est erron (n'existe pas dans la base)
			return false;
		}
	}

	private function authenticate_ldap($_login,$_password) {
		if ($_login == null || $_password == null) {
	        return false;
	        exit();
	    }
	    $ldap_server = new LDAPServer;
	    if ($ldap_server->authenticate_user($_login,$_password)) {
	    	$this->login = $_login;
	    	$this->current_auth_mode = "ldap";
	    	return true;
	    } else {
	    	return false;
	    }
	}

	private function authenticate_cas() {
		include_once('CAS.php');
		if ($GLOBALS['mode_debug']) {
		    phpCAS::setDebug($GLOBALS['debug_log_file']);
                }
		// config_cas.inc.php est le fichier d'informations de connexions au serveur cas
		$path = dirname(__FILE__)."/../secure/config_cas.inc.php";
		include($path);

		// Le premier argument est la version du protocole CAS
		phpCAS::client(CAS_VERSION_2_0, $cas_host, $cas_port, $cas_root, false);
		phpCAS::setLang('french');

		// redirige vers le serveur d'authentification si aucun utilisateur authentifi n'a
		// t trouv par le client CAS.
		phpCAS::setNoCasServerValidation();

		// Gestion du single sign-out
		phpCAS::handleLogoutRequests(false);
		
		// Authentification
		phpCAS::forceAuthentication();

		$this->login = phpCAS::getUser();

		// On rinitialise la session
		session_name("GEPI");
		session_start();
		$_SESSION['login'] = $this->login;

		$this->current_auth_mode = "sso";

		return true;
	}

	public function logout_cas() {
		include_once('CAS.php');

		// config_cas.inc.php est le fichier d'informations de connexions au serveur cas
		$path = dirname(__FILE__)."/../secure/config_cas.inc.php";
		include($path);

		// Le premier argument est la version du protocole CAS
		phpCAS::client(CAS_VERSION_2_0,$cas_host,$cas_port,$cas_root,'');
		phpCAS::setLang('french');
		if ($cas_use_logout) {
			phpCAS::logout();
		}else{
			if ($cas_logout_url != '') {
				header("Location:".$cas_logout_url);
				exit();
			}else{
				// Il faudra trouver mieux
				echo '<html><head><title>GEPI</title></head><body><h2>Vous &ecirc;tes d&eacute;connect&eacute;.</h2></body></html>';
				exit();
			}

		}
		// redirige vers le serveur d'authentification si aucun utilisateur authentifi n'a
		// t trouv par le client CAS.
		//phpCAS::setNoCasServerValidation();
		//phpCAS::forceAuthentication();

		//$this->login = phpCAS::getUser();

		// On rinitialise la session
		//session_name("GEPI");
		//session_start();
		//$_SESSION['login'] = $this->login;

		//$this->current_auth_mode = "sso";

		return true;
	}

	private function authenticate_lemon() {
		#TODO: Vrifier que a marche bien comme a !!
	  if (isset($_GET['login'])) $login = $_GET['login']; else $login = "";
	  if (isset($_COOKIE['user'])) $cookie_user = $_COOKIE['user']; else $cookie_user="";
	  if(empty($cookie_user) or $cookie_user != $login) {
	  	return false;
	  } else {
		$this->login = $login;
		$this->current_auth_mode = "sso";
	  	return true;
	  }
	}

	private function authenticate_lcs() {
		/*
		include LCS_PAGE_AUTH_INC_PHP;
		include LCS_PAGE_LDAP_INC_PHP;
		# LCS a besoin de quelques variables extrieures...
		# L'initialisation ci-dessous n'est pas trs propre, il faudra
		# reprendre a...
		*/
		global $login, $idpers;

		$DBAUTH = $GLOBALS['DBAUTH'];
		$HTTP_COOKIE_VARS = $GLOBALS['HTTP_COOKIE_VARS'];
		$authlink = $GLOBALS['authlink'];
		$dbHost = $GLOBALS['dbHost'];
		$dbUser = $GLOBALS['dbUser'];
		$dbPass = $GLOBALS['dbPass'];
		$db_nopersist = $GLOBALS['db_nopersist'];
		$dbDb = $GLOBALS['dbDb'];

		//list ($idpers,$login) = isauth();
		if ($idpers) {
			list($user, $groups)=people_get_variables($login, false);
			#TODO: Utiliser les infos des lignes ci-dessous pour mettre  jour
			# les informations de l'utilisateur dans la base.
			$lcs_tab_login["nom"] = $user["nom"];
			$lcs_tab_login["email"] = $user["email"];
			$long = strlen($user["fullname"]) - strlen($user["nom"]);
			$lcs_tab_login["fullname"] = substr($user["fullname"], 0, $long) ;

			// A ce stade, l'utilisateur est authentifi
			// Etablir  nouveau la connexion  la base
			if (empty($db_nopersist))
				$db_c = mysql_pconnect($dbHost, $dbUser, $dbPass);
			else
				$db_c = mysql_connect($dbHost, $dbUser, $dbPass);

			if (!$db_c || !mysql_select_db ($dbDb)) {
				echo "\n<p>Erreur : Echec de la connexion  la base de donnes";
				exit;
			}
			$this->login = $login;
			$this->current_auth_mode = "sso";
			return true;
			exit;
		} else {
			// L'utilisateur n'a pas t identifi'
			header("Location:".LCS_PAGE_AUTHENTIF);
			exit;
		}
	}

	# Cette mthode charge en session les donnes de l'utilisateur,
	#  la suite d'une authentification russie.
	private function load_user_data() {
		# Petit test de dpart pour tre sr :
		if (!$this->login || $this->login == null) {
			return false;
			exit();
		}

		# Gestion du multisite : on a besoin du RNE de l'utilisateur.
		if (isset($GLOBALS['multisite']) && $GLOBALS['multisite'] == 'y' && LDAPServer::is_setup()) {
			$ldap = new LDAPServer;
			$user = $ldap->get_user_profile($this->login);
			$this->rne = $user["rne"][0];
		}

		# On regarde si on doit utiliser un login en majuscule. Si c'est le cas, il faut imprativement
		# le faire *aprs* un ventuel import externe.
		if ($this->use_uppercase_login($this->login)) {
			$this->login = strtoupper($this->login);
		}

		# On interroge la base de donnes
		$query = mysql_query("SELECT nom, prenom, statut, etat, now() start, change_mdp, auth_mode FROM utilisateurs WHERE (login = '".$this->login."')");

		# Est-ce qu'on a bien une entre ?
		if (mysql_num_rows($query) != "1") {
			return false;
			exit();
		}

		$sql = "SELECT id_matiere FROM j_professeurs_matieres WHERE (id_professeur = '" . $this->login . "') ORDER BY ordre_matieres LIMIT 1";
        $matiere_principale = sql_query1($sql);

		$row = mysql_fetch_object($query);

	    $_SESSION['login'] = $this->login;
	    $_SESSION['prenom'] = $row->prenom;
	    $_SESSION['nom'] = $row->nom;
	    $_SESSION['statut'] = $row->statut;
	    $_SESSION['start'] = $row->start;
	    $_SESSION['matiere'] = $matiere_principale;
	    $_SESSION['rne'] = $this->rne;
	    $_SESSION['current_auth_mode'] = $this->current_auth_mode;

	    # L'tat de l'utilisateur n'est pas stock en session, mais seulement en interne
	    # pour pouvoir effectuer quelques tests :
	    $this->etat = $row->etat;

		// Ajout pour les statuts privs
	    if ($_SESSION['statut'] == 'autre') {

	    	// On charge aussi le statut spcial
	    	$sql = "SELECT ds.id, ds.nom_statut FROM droits_statut ds, droits_utilisateurs du
											WHERE du.login_user = '".$this->login."'
											AND du.id_statut = ds.id";
			$query = mysql_query($sql);
			$result = mysql_fetch_array($query);

			$_SESSION['statut_special'] = $result['nom_statut'];
			$_SESSION['statut_special_id'] = $result['id'];

	    }

		$length = rand(35, 45);
		for($len=$length,$r='';strlen($r)<$len;$r.=chr(!mt_rand(0,2)? mt_rand(48,57):(!mt_rand(0,1) ? mt_rand(65,90) : mt_rand(97,122))));
		$_SESSION["gepi_alea"] = $r;

	    # On charge les donnes dans l'instance de Session.
	    $this->load_session_data();
	    return true;
	}

	private function record_failed_login($_login) {
		# Une tentative de login avec un mot de passe erronne a t dtecte.
		$test_login = sql_count(sql_query("SELECT login FROM utilisateurs WHERE (login = '".$_login."')"));

		if ($test_login != "0") {
			tentative_intrusion(1, "Tentative de connexion avec un mot de passe incorrect. Ce peut tre simplement une faute de frappe. Cette alerte n'est significative qu'en cas de rptition. (login : ".$_login.")");
			# On a un vrai login.
			# On enregistre un log d'erreur de connexion.
	        $sql = "insert into log (LOGIN, START, SESSION_ID, REMOTE_ADDR, USER_AGENT, REFERER, AUTOCLOSE, END) values (
	        	'" . $_login . "',
	            now(),
	            '',
	            '" . $_SERVER['REMOTE_ADDR'] . "',
	            '" . $_SERVER['HTTP_USER_AGENT'] . "',
	            '" . $_SERVER['HTTP_REFERER'] . "',
	            '4',
	            now());";
	        $res = sql_query($sql);

	        // On compte de nombre de tentatives infructueuse issues de la mme adresse IP
	        $sql = "select LOGIN from log where
	                LOGIN = '" . $_login . "' and
	                START > now() - interval " . getSettingValue("temps_compte_verrouille") . " minute and
	                REMOTE_ADDR = '".$_SERVER['REMOTE_ADDR']."'
	                ";
	        $res_test = sql_query($sql);
	        if (sql_count($res_test) > getSettingValue("nombre_tentatives_connexion")) {
	        	$this->lock_account($_login);
	        	return true;
	        } else {
	        	return false;
	        }
		} else {
			tentative_intrusion(1, "Tentative de connexion avec un login incorrect (n'existe pas dans la base Gepi). Ce peut tre simplement une faute de frappe. Cette alerte n'est significative qu'en cas de rptition. (login utilis : ".$_login.")");
			// Le login n'existe pas. On fait donc un test sur l'IP.
			$sql = "select LOGIN from log where
                START > now() - interval " . getSettingValue("temps_compte_verrouille") . " minute and
                REMOTE_ADDR = '".$_SERVER['REMOTE_ADDR']."'";
            $res_test = sql_query($sql);
            if (sql_count($res_test) <= 10) {
				// On a moins de 10 enregistrements. On enregistre et on ne renvoie pas de code
				// de verrouillage.
            	$sql = "insert into log (LOGIN, START, SESSION_ID, REMOTE_ADDR, USER_AGENT, REFERER, AUTOCLOSE, END) values (
                    '" . $_login . "',
                    now(),
                    '',
                    '" . $_SERVER['REMOTE_ADDR'] . "',
                    '" . $_SERVER['HTTP_USER_AGENT'] . "',
                    '" . $_SERVER['HTTP_REFERER'] . "',
                    '4',
                    now()
                    )
                    ;";
                $res = sql_query($sql);
                return false;
            } else {
            	// On a 10 entres, on renvoie un code d'erreur de verouillage.
            	return true;
            }
		}
	}

	# Verrouillage d'un compte en raison d'un trop grand nombre d'chec de connexion.
	private function lock_account($_login) {
       if ((!isset($GLOBALS['bloque_compte_admin'])) or ($GLOBALS['bloque_compte_admin'] != "n")) {
          // On verrouille le compte mme si c'est un admin
          $reg_data = sql_query("UPDATE utilisateurs SET date_verrouillage=now() WHERE login='".$_login."'");
       } else {
          // on ne bloque pas le compte d'un administrateur
          $reg_data = sql_query("UPDATE utilisateurs SET date_verrouillage=now() WHERE login='".$_login."' and statut!='administrateur'");
       }
       # On enregistre une alerte de scurit.
       tentative_intrusion(2, "Verrouillage du compte ".$_login." en raison d'un trop grand nombre de tentatives de connexion infructueuses. Ce peut tre une tentative d'attaque brute-force.");
       return true;
	}

	# Renvoie true ou false selon que le compte est bloqu ou non.
	private function account_is_locked() {
		$test_verrouillage = sql_query1("select login, statut from utilisateurs where
			login = '" . $this->login . "' and
			date_verrouillage > now() - interval " . getSettingValue("temps_compte_verrouille") . " minute ");

		if ($test_verrouillage != "-1") {
			// Le compte est verrouill.
			if ($this->statut == "administrateur" and $GLOBALS['bloque_compte_admin'] != "n") {
				// On ne veut pas bloquer le compte admin, alors on renvoie false.
				return false;
			} else {
				return true;
			}
		} else {
			return false;
		}
	}

	private function import_user_profile() {
		# On ne peut arriver ici quand dans le cas o on a une authentification russie.
		# L'import d'un utilisateur ne peut se faire qu' partir d'un LDAP
		if (!LDAPServer::is_setup()) {
			return false;
			die();
		} else {
			# Le serveur LDAP est configur, on y va.
			# Encore un dernier petit test quand mme : est-ce que l'utilisateur
			# est bien absent de la base.
			$sql = mysql_query("SELECT login FROM utilisateurs WHERE (login = '".$this->login."')");
			if (mysql_num_rows($sql) != "0") {
				return false;
				die();
			}

			$ldap_server = new LDAPServer;
			$user = $ldap_server->get_user_profile($this->login);
			if ($user) {
				# On ne refait pas de tests ou de formattage. La mthode get_user_profile
				# s'occupe de tout.
				$res = mysql_query("INSERT INTO utilisateurs SET
										login = '".$this->login."',
										prenom = '".$user["prenom"]."',
										nom = '".$user["nom"]."',
										email = '".$user["email"]."',
										civilite = '".$user["civilite"]."',
										statut = '".$user["statut"]."',
										password = '',
										etat = 'actif',
										auth_mode = '".$this->current_auth_mode."',
										change_mdp = 'n'");
				if (!$res) {
					return false;
				} else {
					return true;
				}
			} else {
				return false;
			}
		}
	}


	private function import_user_profile_from_scribe() {
		# On ne peut arriver ici quand dans le cas o on a une authentification russie.
		# L'import d'un utilisateur ne peut se faire qu' partir d'un LDAP de Scribe, ici.
		if (!LDAPServer::is_setup()) {
			return false;
			die();
		} else {
      
      // config_cas.inc.php est le fichier d'informations de connexions au serveur cas
      $path = dirname(__FILE__)."/LDAPServerScribe.class.php";
      include($path);
      
			# Le serveur LDAP est configur, on y va.
			# Encore un dernier petit test quand mme : est-ce que l'utilisateur
			# est bien absent de la base.
			$sql = mysql_query("SELECT login FROM utilisateurs WHERE (login = '".$this->login."')");
			if (mysql_num_rows($sql) != "0") {
				return false;
				die();
			}

			$ldap_server = new LDAPServerScribe;
      
			$user = $ldap_server->get_user_profile($this->login);
			if ($user) {
				# On ne refait pas de tests ou de formattage. La mthode get_user_profile
				# s'occupe de tout.
        
        $errors = false;
        
        // On s'occupe de tous les traitements spcifiques  chaque statut
        
        // Eleve
        if ($user['statut'] == 'eleve') {
          // On a un lve : on vrifie s'il existe dans la table 'eleves',
          // sur la base de son INE, ou nom et prnom.
          $test = mysql_num_rows(mysql_query("SELECT * FROM eleves
                                                WHERE (no_gep = '".$user['raw']['ine'][0]."'
                                                        OR (nom = '".$user['nom']."' AND prenom = '".$user['prenom']."'))"));
          if ($test == 0) {
            // L'lve n'existe pas du tout. On va donc le crer.
            $nouvel_eleve = new Eleve();
            $nouvel_eleve->setLogin($this->login);
            $nouvel_eleve->setNom($user['nom']);
            $nouvel_eleve->setPrenom($user['prenom']);
            $nouvel_eleve->setSexe($user['raw']['entpersonsexe'][0]);
            
            $naissance = $user['raw']['entpersondatenaissance'][0];
            if ($naissance != '') {
              $annee = substr($naissance, 0, 4);
              $mois = substr($naissance, 4, 2);
              $jour = substr($naissance, 6, 2);
            } else {
              $annee = '0000';
              $mois = '00';
              $jour = '00';
            }
            
            $nouvel_eleve->setNaissance("$annee-$mois-$jour");
            $nouvel_eleve->setLieuNaissance('');
            $nouvel_eleve->setElenoet($user['raw']['employeenumber'][0] || '');
            $nouvel_eleve->setEreno('');
            $nouvel_eleve->setEleid($user['raw']['intid'][0] || '');
            $nouvel_eleve->setNoGep($user['raw']['ine'][0] || '');
            $nouvel_eleve->setEmail($user['email']);
            
            if (!$nouvel_eleve->save()) $errors = true;
            
            /*
             * Rcupration des CLASSES de l'eleve :
             * Pour chaque eleve, on parcours ses classes, et on ne prend que celles
             * qui correspondent  la branche de l'tablissement courant, et on les stocke
             */
            $nb_classes = $user['raw']['enteleveclasses']['count'];

            // Pour chaque classe trouve..
            $eleve_added_to_classe = false;
            for ($cpt=0; $cpt<$nb_classes; $cpt++) {
                if ($eleve_added_to_classe) break;
                $classe_from_ldap = explode("$", $user['raw']['enteleveclasses'][$cpt]);
                // $classe_from_ldap[0] contient le DN de l'tablissement
                // $classe_from_ldap[1] contient l'id de la classe
                $code_classe = $classe_from_ldap[1];

                // Si le SIREN de la classe trouve correspond bien au SIREN de l'tablissement courant,
                // on cre une entre correspondante dans le tableau des classes disponibles
                // Sinon c'est une classe d'un autre tablissement, on ne doit donc pas en tenir compte
                if (strcmp($classe_from_ldap[0], $ldap_server->get_base_branch()) == 0) {

                    /*
                     * On test si la classe que l'on souhaite ajouter existe dj
                     * en la cherchant dans la base (
                     */
                    $classe_courante = ClasseQuery::create()
                          ->filterByClasse($code_classe)
                          ->findOne();

                    if ($classe_courante) {
                      
                      foreach($classe_courante->getPeriodeNotes() as $periode) {
                          // On associe l'lve  la classe
                          $res = mysql_query("INSERT INTO j_eleves_classes SET
                              login = '".$this->login."', 
                              id_classe = '".$classe_courante->getId()."',
                              periode = '".$periode->getNumPeriode()."'");
                      } // Fin boucle priodes
                      $eleve_added_to_classe = true;
                    } // Fin test classe
                } //Fin du if classe appartient a l'etablissement courant
            } //Fin du parcours des classes de l'eleve

            
            // On a maintenant un lve en base, qui appartient  sa classe
            // pour toutes les priodes  partir de la priode courante
            
            // On ne l'associe pas aux enseignements, car c'est un peu trop
            // risqu et bancal pour tre ralis dynamiquement ici, dans
            // la mesure o l'on n'a pas une information prcise sur la
            // composition des groupes.
            
            
          } else {
            // L'lve existe dj dans la base. On ne cr que l'utilisateur correspondant.
            // Pour a, on va devoir s'assurer que l'identifiant est identique !
            $test_login = mysql_result(mysql_query("SELECT login FROM eleves
                                                WHERE (no_gep = '".$user['raw']['ine'][0]."'
                                                        OR (nom = '".$user['nom']."' AND prenom = '".$user['prenom']."'))"), 0);
            if ($test_login != $this->login) {
              // Le login est diffrent, on ne peut rien faire... Il faudrait renommer
              // le login partout dans l'application, mais il n'existe pas de mcanisme
              // pour le faire de manire fiable.
              $errors = true;
            }
          }
          
        } elseif ($user['statut'] == 'responsable') {
          // Si on a un responsable, il faut l'associer  un lve
          
          $resp = new ResponsableEleve();
          $resp->setLogin($this->login);
          $resp->setNom($user['nom']);
          $resp->setPrenom($user['prenom']);
          $resp->setCivilite($user['raw']['personaltitle'][0]);
          $resp->setTelPers($user['raw']['homephone'][0]);
          $resp->setTelProf($user['raw']['telephonenumber'][0]);
          $resp->setTelPort($user['raw']['mobile'][0]);
          $resp->setMel($user['email']);
          $resp->setPersId($user['raw']['intid'][0]);
                    
          // On cr l'adresse associe
          
          $adr = new ResponsableEleveAdresse();
          $adr->setAdrId($user['raw']['intid'][0]);
          $adr->setAdr1($user['raw']['entpersonadresse'][0]);
          $adr->setAdr2('');
          $adr->setAdr3('');
          $adr->setAdr4('');
          $adr->setCommune($user['raw']['entpersonville'][0]);
          $adr->setCp($user['raw']['entpersoncodepostal'][0]);
          $adr->setPays($user['raw']['entpersonpays'][0]);
          
          $resp->setResponsableEleveAdresse($adr);
          
          $resp->save();

          $nb_eleves_a_charge = $user['raw']['entauxpersreleleveeleve']['count'];

          //pour chaque dn d'eleve
          for ($i=0;$i<$nb_eleves_a_charge;$i++) {
              $eleve_uid = explode(",",$user['raw']['entauxpersreleleveeleve'][$i]);
              $eleve_associe_login = substr($eleve_uid[0], 4);
              $eleve_query = mysql_query("SELECT ele_id FROM eleves WHERE login = '$eleve_associe_login'");
              if (mysql_num_rows($eleve_query) == 1) {
                $eleve_associe_ele_id = mysql_result($eleve_query, 0);
                  
                // Gepi donne un ordre aux responsables, il faut donc verifier combien de responsables sont deja enregistres pour l'eleve
                // On initialise le numero de responsable
                $numero_responsable = 1;
                $req_nb_resp_deja_presents = "SELECT count(*) FROM responsables2 WHERE ele_id = '$eleve_associe_ele_id'";
                $res_nb_resp = mysql_query($req_nb_resp_deja_presents);
                $nb_resp = mysql_fetch_array($res_nb_resp);
                if ($nb_resp[0] > 0) {
                    // Si deja 1 ou plusieurs responsables legaux pour cet eleve,on ajoute le nouveau responsable en incrementant son numero
                    $numero_responsable += $nb_resp[0];

                    //--
                    // TODO: tester si on a des adresses identiques, et n'utiliser qu'un seul objet adresse dans ce cas.
                    //--
                }

                // Ajout de la relation entre Responsable et Eleve dans la table "responsables2" pour chaque eleve
                $req_ajout_lien_eleve_resp = "INSERT INTO responsables2 VALUES('$eleve_associe_ele_id','".$resp->getPersId()."','$numero_responsable','')";
                mysql_query($req_ajout_lien_eleve_resp);
              } // Fin test si lve existe
          }
          
        } elseif ($user['statut'] == 'professeur') {
          // Rien de spcial  ce stade.
          
        } else {
          // Ici : que fait-on si l'on n'a pas un statut directement reconnu
          // et compatible Gepi ?
          // On applique le statut par dfaut, configur par l'admin.
          $user['statut'] = getSettingValue("statut_utilisateur_defaut");
        }
        
        // On cr l'utilisateur, s'il n'y a pas eu d'erreurs.
        if (!$errors) {
            $new_compte_utilisateur = new UtilisateurProfessionnel();
            $new_compte_utilisateur->setAuthMode('sso');
            $new_compte_utilisateur->setCivilite($user['civilite']);
            $new_compte_utilisateur->setEmail($user['email']);
            $new_compte_utilisateur->setEtat('actif');
            $new_compte_utilisateur->setLogin($this->login);
            $new_compte_utilisateur->setNom($user['nom']);
            $new_compte_utilisateur->setPrenom($user['prenom']);
            $new_compte_utilisateur->setShowEmail('no');
            $new_compte_utilisateur->setStatut($user['statut']);
            $new_compte_utilisateur->save();
        }
        
			} else {
				return false;
			}
		}
	}





	# Cette mthode sert  forcer PHP et MySQL  utiliser un fuseau horaire
	# particulier.
	# Le fuseau horaire est simplement paramtr dans connect.inc.php,
	# en assignant $timezone.
	private function update_timezone($_timezone) {

	    # Mise  jour du fuseau horaire pour PHP
	    $update_timezone = date_default_timezone_set($_timezone);

	    # Mise  jour pour MySQL
	    if ($update_timezone) {

		# Il faut qu'on formatte le fuseau
		$timezone = new DateTimeZone(date_default_timezone_get());
		$time = new DateTime("now", $timezone);
		$offset = $timezone->getOffset($time);
		$offset_sign = $offset < 0 == "-" ? "-" : "+";
		$offset = abs($offset);
		$offset_hours = $offset / 3600 % 24;
		$offset_hours = strlen($offset_hours) == '1' ? "0".$offset_hours : $offset_hours;
		$offset_minutes = $offset / 60 % 60;
		$offset_minutes = strlen($offset_minutes) == '1' ? "0".$offset_minutes : $offset_minutes;
		$mysql_offset = $offset_sign . $offset_hours . ":" . $offset_minutes;
		$test = mysql_query("SET time_zone = '".$mysql_offset."'");
	    }
	    return $update_timezone;
        }
}
?>
