<?php
/**
 * @version : $Id: index.php 4444 2010-05-15 19:32:19Z delineau $
 *
 * Copyright 2001, 2009 Thomas Belliard, Julien Jocal
 *
 * This file is part of GEPI.
 *
 * GEPI is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GEPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GEPI; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * Ce fichier est destin  organiser les plugins de Gepi.
 * Il permet d'ajouter ses propres plugins.
 * Une documentation est disponible : http://projects.sylogix.org/gepi/wiki/plugin
 */

// On initialise
$affiche_connexion = 'yes';
$niveau_arbo = 1;

// Initialisations files et autres librairies
include("../lib/initialisations.inc.php");
include("../lib/initialisationsPropel.inc.php");
include 'traiterXml.class.php';
include 'traiterRequetes.class.php';

// Resume session et on vrifie les droits de l'utilisateur
$resultat_session = $session_gepi->security_check();
if ($resultat_session == 'c') {
  header("Location:utilisateurs/mon_compte.php?change_mdp=yes&retour=accueil#changemdp");
  die();
} else if ($resultat_session == '0') {
  header("Location: ../logout.php?auto=1");
  die();
}
if (!checkAccess()) {
	header("Location: ../logout.php?auto=1");
  die();
}


// =========================================== VARIABLES =================================================== //
$plugin_id    = isset($_GET["plugin_id"]) ? $_GET["plugin_id"] : NULL;
$nom_plugin   = isset($_GET["nom_plugin"]) ? $_GET["nom_plugin"] : NULL;
$action       = isset($_GET["action"]) ? $_GET["action"] : NULL;
$_erreur      = isset($_GET["_erreur"]) ? $_GET["_erreur"] : NULL;
$_msg         = NULL;


// ========================================== CODE METIER ================================================== //
function aff_debug($tab){
  echo '<pre>';
  print_r($tab);
  echo '</pre>';
}

# On traite d'un plugin qui n'est pas install
if (isset($nom_plugin)){
  if ($action == "installer"){
    // On ouvre le rpertoire et on scanne le contenu, il faut y trouver un fichier xml et un fichier index.php au minimum
    $plugin = scandir($nom_plugin);
    // On vrifie que le plugin.xml est bien prsent
    $testXML = false;
    foreach ($plugin as $fichier){
      if ($fichier == "plugin.xml"){
        $testXML = true;
      }
    }

    if ($testXML){

      // On lit le fichier xml
      $xml = simplexml_load_file($nom_plugin . "/plugin.xml");
      $testXML = new traiterXml($xml);

      if ($testXML->getReponse() === true){
        // alors on peut envoyer le xml pour installer le plugin
        $new_plugin = PlugInPeer::addPluginComplet($xml);
        /**
         * On traite les requtes demandes lors de l'installation
         */
        $traitement_requetes = new traiterRequetes($xml->installation->requetes);
        if ($traitement_requetes->getReponse() === true){
          // C'est fait les requtes ont t excutes
        }else{
          $_msg = '<p class="red">ERREUR(r) : ' . $traitement_requetes->getErreur() . '</p>';
        }
      }else{

        $_msg = '<p class="red">ERREUR(x) : ' . $testXML->getErreur() . '</p>';

      }

    }else{

      header("index.php?_erreur=1");
      exit();

    }

  }
# On traite des plugin dj installs
}elseif(isset($plugin_id)){
  // On s'attache  faire les actions demandes sur ce plugin dj install
  $pluginAmodifier = PlugInPeer::retrieveByPK($plugin_id);
  switch ($action) {
    case "desinstaller":
      $xml = simplexml_load_file($pluginAmodifier->getNom() . "/plugin.xml");
      $pluginAmodifier->delete();
      $traitement_requetes = new traiterRequetes($xml->desinstallation->requetes);
      break;
    case "ouvrir":
      $pluginAmodifier->ouvrePlugin();
      break;
    case "fermer":
      $pluginAmodifier->fermePlugin();
      break;

  default:
    $_msg = "<p>L'action demand&eacute;e n'existe pas !</p>";
    break;
  }
}

# On liste les plugins
$liste_plugins  = array();
$open_dir       = scandir("./");

foreach ($open_dir as $dir){

  // On vrifie la prsence d'un point dans le nom retourn
  $test = explode(".", $dir);
  if (count($test) <= 1){

    $test2 = PlugInPeer::getPluginByNom($dir);

    if (is_object($test2)){
      $liste_plugins[] = $test2;
    }else{
      $liste_plugins[] = $dir;
    }

  }

}

# Gestion des erreurs
switch ($_erreur) {
  case "1":
    $_msg = "<p class=\"red\">Il manque le fichier plugin.xml &agrave; ce plugin, impossible de l'installer !</p>";
    break;
  case "2":
    $_msg = "<p class=\"red\">Le fichier plugin.xml ne respecte pas la struture demand&eacute;e ! voir <a href=\"http://projects.sylogix.org/gepi/wiki/plugin\">la page sur TRAC</a></p>";
    break;

default:
  //$_msg = NULL;
  break;
}
// ================= HEADER ========================//
$titre_page = "Param&eacute;trer les plugins";
include '../lib/header.inc';
// ================ FIN HEADER =====================//
//print_r($liste_plugins);
//aff_debug($testXML);
?>


<h3 class="Gepi">Liste des plugins install&eacute;s</h3>
<p>Pour plus d'informations concernant les plugins de Gepi, voyez
  <a onclick="window.open(this.href, '_blank'); return false;" href="http://projects.sylogix.org/gepi/wiki/plugin">la page sur TRAC</a>
</p>
<?php echo $_msg; ?>
 <table class="table">
  <tr>
    <th>Plugin</th>
    <th>Description</th>
    <th>Auteur</th>
    <th>Version</th>
    <th>Install&eacute; ?</th>
    <th>Ouvert ?</th>
  </tr>
<?php
foreach($liste_plugins as $plugin){
  if (!is_object($plugin)){
    // le plugin n'est pas install
    echo '
    <tr>
      <td>'.str_replace("_", " ", $plugin).'</td>
      <td>-</td>
      <td>-</td>
      <td>-</td>
      <td><a href="index.php?nom_plugin='.$plugin.'&amp;action=installer" title="Voulez-vous l\'installer ?">NON</a></td>
      <td>NON</td>
    </tr>';
  }else{
    // Le plugin est install
    $xml = simplexml_load_file($plugin->getNom() . "/plugin.xml");
    // On teste s'il est ouvert
    if ($plugin->getOuvert() == 'y'){
      $aff_ouvert = '<a href="index.php?plugin_id='.$plugin->getId().'&amp;action=fermer" title="Voulez-vous le fermer ?">OUI</a>';
    }else{
      $aff_ouvert = '<a href="index.php?plugin_id='.$plugin->getId().'&amp;action=ouvrir" title="Voulez-vous l\'ouvrir ?">NON</a>';
    }
    echo '
    <tr>
      <td>'.str_replace("_", " ", $plugin->getNom()).'</td>
      <td>'.iconv("utf-8","iso-8859-1",$xml->description).'</td>
      <td>'.iconv("utf-8","iso-8859-1",$xml->auteur).'</td>
      <td>'.iconv("utf-8","iso-8859-1",$xml->version).'</td>
      <td><a href="index.php?plugin_id='.$plugin->getId().'&amp;action=desinstaller" title="Voulez-vous le d&eacute;sinstaller ?" onclick="return confirm('."'La desinstallation d\'un plugin entrane la suppression des tables ventuellement associes et des donnes qu\'elles contiennent. Etes-vous sr de vouloir dsinstaller ce plugin ?'".');">OUI</a></td>
      <td>'.$aff_ouvert.'</td>
    </tr>';
  }
}
?>

</table>

<?php include '../lib/footer.inc.php'; ?>