<?php
/**
 * @version : $Id: traiterRequetes.class.php 4465 2010-05-18 14:36:49Z delineau $
 *
 * Copyright 2001, 2009 Thomas Belliard, Laurent Delineau, Edouard Hue, Eric Lebrun, Julien Jocal
 *
 * This file is part of GEPI.
 *
 * GEPI is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GEPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GEPI; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * Classe qui permet de vrifier les requtes demandes par un plugin lors de son installation
 * Des mthodes permettent ensuite de lancer ces requtes
 *
 * @author jjocal
 */
class traiterRequetes {

    /**
   * Rponse donne aprs la vrification.
   *
   * @var boolean
   */
  private $_reponse = false;

  /**
   * Message d'erreur renvoy par les diffrentes vrifications
   *
   * @var string Message d'erreur
   */
  private $erreur = NULL;

  /**
   * On stocke les requtes dans cet attribut
   *
   * @var string La requte demande
   */
  private $_requetes = NULL;

  /**
   * Dtermine la liste des type de requtes possibles
   *
   * @var array Liste des requtes possibles
   */
  private $_requetes_possibles = array('insert', 'INSERT', 'create', 'CREATE', 'update', 'UPDATE', 'drop', 'DROP');

  /**
   * Vrification et envoie des requtes par Propel::PDO
   *
   * @param object $requetes simpleXMLElement
   */
  public function  __construct(simpleXMLElement $requetes) {

    $this->_requetes = $requetes;
    if (count($this->_requetes->requete)==0)
            $this->_reponse = true;
    foreach ($this->_requetes->requete as $requete) {
      // On est face  une liste de requtes
      if (trim($requete)=='') {
        $this->_reponse = true;
      }else
      if ($this->verifRequete($requete) === true){
        $this->insertRequete($requete);
      }else{
        $this->retourneErreur(1, $requete);
      }
    }

  }

  /**
   * Mthode de vrification de la structure des requtes SQL des plugins
   *
   * @param string $requete
   * @return boolean false/true
   */
  protected function verifRequete($requete){
    $test = explode(" ", trim($requete));
    if (in_array($test[0], $this->_requetes_possibles)){
      if (in_array($test[0], array('drop', 'DROP'))){
        if (in_array($test[1], array('table', 'TABLE'))){
          return true;
        }else{
          return false;
        }
      }else{
        return true;
      }
    }else{
      return false;
    }

  }

  /**
   * Mthode qui permet de lancer des requtes SQL vers la base lors de la cration d'un plugin
   *
   * @param string $requete Requte SQL
   */
  protected function insertRequete($requete){

    $con = Propel::getConnection();
    if ($con->exec($requete) !== false){
      $this->_reponse = true;
    }else{
      $this->_reponse = false;
    }

  }

  /**
   * Mthode qui retourne un type d'erreur et un message qui prcise o se situe l'erreur.
   *
   * @param integer $_e Type d'erreur
   * @param string $_m noeud li  cette erreur
   */
  private function retourneErreur($_e, $_m){
    switch ($_e) {
      case 1:
        $message = 'La requte ' . $_m . ' dans le fichier plugin.xml ne passe pas !';
        break;
      case 2:
        $message = '';
        break;
      case 3:
        $message = '';
        break;

      default:
        $message = "pas de message d'erreur";
      break;
    }
    $this->erreur = $message;
  }

  /**
   * Mthode qui renvoie une erreur si elle existe
   *
   * @return string Message d'erreur
   */
  public function getErreur(){
    return $this->erreur;
  }

  /**
   * Mthode qui renvoie la rponse aprs traitement des requtes
   *
   * @return boolean false/true
   */
  public function getReponse(){
    return $this->_reponse;
  }

}
?>
